@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2015 National ICT Australia (NICTA)
+// Copyright (C) 2012-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -143,6 +143,52 @@ spop_cx_abs::apply(SpMat<typename T1::pod_type>& out, const mtSpOp<typename T1::
 
 
 
+namespace priv
+  {
+  struct functor_arg
+    {
+    template<typename eT>
+    arma_inline eT operator()(const eT val) const { return arma_arg<eT>::eval(val); }
+    };
+  }
+
+
+
+template<typename T1>
+inline
+void
+spop_arg::apply(SpMat<typename T1::elem_type>& out, const SpOp<T1,spop_arg>& in)
+  {
+  arma_extra_debug_sigprint();
+  
+  out.init_xform(in.m, priv::functor_arg());
+  }
+
+
+
+namespace priv
+  {
+  struct functor_cx_arg
+    {
+    template<typename T>
+    arma_inline T operator()(const std::complex<T>& val) const { return std::arg(val); }
+    };
+  }
+
+
+
+template<typename T1>
+inline
+void
+spop_cx_arg::apply(SpMat<typename T1::pod_type>& out, const mtSpOp<typename T1::pod_type, T1, spop_cx_arg>& in)
+  {
+  arma_extra_debug_sigprint();
+  
+  out.init_xform_mt(in.m, priv::functor_cx_arg());
+  }
+
+
+
 namespace priv
   {
   struct functor_real
@@ -300,4 +346,119 @@ spop_resize::apply(SpMat<typename T1::elem_type>& out, const SpOp<T1, spop_resiz
 
 
 
+namespace priv
+  {
+  struct functor_floor
+    {
+    template<typename eT>
+    arma_inline eT operator()(const eT val) const { return eop_aux::floor(val); }
+    };
+  }
+
+
+
+template<typename T1>
+inline
+void
+spop_floor::apply(SpMat<typename T1::elem_type>& out, const SpOp<T1,spop_floor>& in)
+  {
+  arma_extra_debug_sigprint();
+  
+  out.init_xform(in.m, priv::functor_floor());
+  }
+
+
+
+namespace priv
+  {
+  struct functor_ceil
+    {
+    template<typename eT>
+    arma_inline eT operator()(const eT val) const { return eop_aux::ceil(val); }
+    };
+  }
+
+
+
+template<typename T1>
+inline
+void
+spop_ceil::apply(SpMat<typename T1::elem_type>& out, const SpOp<T1,spop_ceil>& in)
+  {
+  arma_extra_debug_sigprint();
+  
+  out.init_xform(in.m, priv::functor_ceil());
+  }
+
+
+
+namespace priv
+  {
+  struct functor_round
+    {
+    template<typename eT>
+    arma_inline eT operator()(const eT val) const { return eop_aux::round(val); }
+    };
+  }
+
+
+
+template<typename T1>
+inline
+void
+spop_round::apply(SpMat<typename T1::elem_type>& out, const SpOp<T1,spop_round>& in)
+  {
+  arma_extra_debug_sigprint();
+  
+  out.init_xform(in.m, priv::functor_round());
+  }
+
+
+
+namespace priv
+  {
+  struct functor_trunc
+    {
+    template<typename eT>
+    arma_inline eT operator()(const eT val) const { return eop_aux::trunc(val); }
+    };
+  }
+
+
+
+template<typename T1>
+inline
+void
+spop_trunc::apply(SpMat<typename T1::elem_type>& out, const SpOp<T1,spop_trunc>& in)
+  {
+  arma_extra_debug_sigprint();
+  
+  out.init_xform(in.m, priv::functor_trunc());
+  }
+
+
+
+namespace priv
+  {
+  struct functor_sign
+    {
+    template<typename eT>
+    arma_inline eT operator()(const eT val) const { return eop_aux::sign(val); }
+    };
+  }
+
+
+
+template<typename T1>
+inline
+void
+spop_sign::apply(SpMat<typename T1::elem_type>& out, const SpOp<T1,spop_sign>& in)
+  {
+  arma_extra_debug_sigprint();
+  
+  out.init_xform(in.m, priv::functor_sign());
+  }
+
+
+
 //! @}
